"""
Convenient management of datasets

- Placeholder
"""

__author__ = """Brendan Strejcek"""
__email__ = 'brendan@datagazing.com'
__version__ = '0.1.0'

# from .datashelf import SomeClass # noqa F401



"""See top level package docstring for documentation"""

import logging
import os
import pathlib

import attr

myself = pathlib.Path(__file__).stem

logger = logging.getLogger(myself)
logging.getLogger(myself).addHandler(logging.NullHandler())

########################################################################

def main():
    pass

if __name__ == '__main__':
    main()
